@@ -1,29 +1,13 @@
 from typing import Type, TYPE_CHECKING
-import math
 
 if TYPE_CHECKING:
     from pyteamtv.models.sporting_event import SportingEvent
 
-    import pandas as pd
-
 from pyteamtv.infra.requester import Requester
 from pyteamtv.models.list import List
 from pyteamtv.models.observation import Observation
 
 
-def pol2cart(angle: float, distance: float):
-    if angle > 90:
-        angle -= 360
-    angle += 90
-
-    phi = (angle / 360) * 2 * math.pi
-    rho = distance
-
-    x = rho * math.cos(phi)
-    y = rho * math.sin(phi)
-    return x, y
-
-
 class ObservationLog(List[Observation]):
     def __init__(
         self,
